@@ -65,9 +65,9 @@ Kwave::App::App(int &argc, char **argv)
 
     // connect the clipboard
     connect(QApplication::clipboard(),
-	    SIGNAL(changed(QClipboard::Mode)),
-	    &(Kwave::ClipBoard::instance()),
-	    SLOT(slotChanged(QClipboard::Mode)));
+            SIGNAL(changed(QClipboard::Mode)),
+            &(Kwave::ClipBoard::instance()),
+            SLOT(slotChanged(QClipboard::Mode)));
 }
 
 //***************************************************************************
@@ -84,33 +84,33 @@ void Kwave::App::processCmdline(QCommandLineParser *cmdline)
     KConfigGroup cfg = KSharedConfig::openConfig()->group("Global");
     result = cfg.readEntry("UI Type");
     if (result == _("SDI")) {
-	m_gui_type = Kwave::App::GUI_SDI;
+        m_gui_type = Kwave::App::GUI_SDI;
     } else if (result == _("MDI")) {
-	m_gui_type = Kwave::App::GUI_MDI;
+        m_gui_type = Kwave::App::GUI_MDI;
     } else if (result == _("TAB")) {
-	m_gui_type = Kwave::App::GUI_TAB;
+        m_gui_type = Kwave::App::GUI_TAB;
     }
     // else: use default
 
     // if user interface type is given as cmdline parameter: use that one
     if (m_cmdline->isSet(_("gui"))) {
-	QString arg = m_cmdline->value(_("gui")).toUpper();
-	bool valid = false;
-	if (arg == _("SDI")) {
-	    m_gui_type = Kwave::App::GUI_SDI;
-	    valid = true;
-	} else if (arg == _("MDI")) {
-	    m_gui_type = Kwave::App::GUI_MDI;
-	    valid = true;
-	} else if (arg == _("TAB")) {
-	    m_gui_type = Kwave::App::GUI_TAB;
-	    valid = true;
-	}
-	// else: use previous setting
+        QString arg = m_cmdline->value(_("gui")).toUpper();
+        bool valid = false;
+        if (arg == _("SDI")) {
+            m_gui_type = Kwave::App::GUI_SDI;
+            valid = true;
+        } else if (arg == _("MDI")) {
+            m_gui_type = Kwave::App::GUI_MDI;
+            valid = true;
+        } else if (arg == _("TAB")) {
+            m_gui_type = Kwave::App::GUI_TAB;
+            valid = true;
+        }
+        // else: use previous setting
 
-	// save this setting
-	if (valid && (arg != result))
-	    cfg.writeEntry(_("UI Type"), arg);
+        // save this setting
+        if (valid && (arg != result))
+            cfg.writeEntry(_("UI Type"), arg);
     }
 }
 
@@ -137,32 +137,32 @@ int Kwave::App::newInstance(const QStringList &args, const QString &dir)
 
     static bool first_time = true;
     if (first_time) {
-	first_time = false;
+        first_time = false;
 
-	// open the log file if given on the command line
-	if (m_cmdline->isSet(_("logfile"))) {
-	    if (!Kwave::Logger::open(m_cmdline->value(_("logfile"))))
-		exit(-1);
-	}
+        // open the log file if given on the command line
+        if (m_cmdline->isSet(_("logfile"))) {
+            if (!Kwave::Logger::open(m_cmdline->value(_("logfile"))))
+                exit(-1);
+        }
 
-	Kwave::Splash::showMessage(i18n("Reading configuration..."));
-	readConfig();
+        Kwave::Splash::showMessage(i18n("Reading configuration..."));
+        readConfig();
 
-	// close when the last window closed
-	connect(this, SIGNAL(lastWindowClosed()), this, SLOT(quit()));
+        // close when the last window closed
+        connect(this, SIGNAL(lastWindowClosed()), this, SLOT(quit()));
     }
 
     QStringList params = m_cmdline->positionalArguments();
 
     // only one parameter -> open with empty window
     if (params.isEmpty()) {
-	retval = newWindow(QUrl());
+        retval = newWindow(QUrl());
     } else {
-	// open a window for each file specified in the
-	// command line an load it
-	foreach (const QString &name, params) {
-	    retval = newWindow(Kwave::URLfromUserInput(name));
-	}
+        // open a window for each file specified in the
+        // command line an load it
+        foreach (const QString &name, params) {
+            retval = newWindow(Kwave::URLfromUserInput(name));
+        }
     }
     return retval;
 }
@@ -178,21 +178,21 @@ int Kwave::App::executeCommand(const QString &command)
 {
     Kwave::Parser parser(command);
     if (parser.command() == _("newwindow")) {
-	int retval = 0;
-	if (parser.hasParams()) {
-	    retval = newWindow(QUrl(parser.params().at(0)));
-	} else {
-	    retval = newWindow(QUrl(QString()));
-	}
-	return (retval == 0) ? 0 : -EIO;
+        int retval = 0;
+        if (parser.hasParams()) {
+            retval = newWindow(QUrl(parser.params().at(0)));
+        } else {
+            retval = newWindow(QUrl(QString()));
+        }
+        return (retval == 0) ? 0 : -EIO;
     } else if (parser.command() == _("openrecent:clear")) {
-	m_recent_files.clear();
-	saveRecentFiles();
-	emit recentFilesChanged();
+        m_recent_files.clear();
+        saveRecentFiles();
+        emit recentFilesChanged();
     } else if (parser.command() == _("help")) {
-	KHelpClient::invokeHelp();
+        KHelpClient::invokeHelp();
     } else {
-	return ENOSYS; // command not implemented (here)
+        return ENOSYS; // command not implemented (here)
     }
     return 0;
 }
@@ -207,7 +207,7 @@ void Kwave::App::addRecentFile(const QString &newfile)
 
     // shorten the list down to (MAX_RECENT_FILES - 1) entries
     while (m_recent_files.count() >= MAX_RECENT_FILES)
-	m_recent_files.removeLast();
+        m_recent_files.removeLast();
 
     // insert the new entry at top
     m_recent_files.prepend(newfile);
@@ -228,48 +228,48 @@ int Kwave::App::newWindow(const QUrl &url)
     Kwave::Splash::showMessage(i18n("Opening main window..."));
 
     switch (m_gui_type) {
-	case Kwave::App::GUI_TAB: /* FALLTHROUGH */
-	case Kwave::App::GUI_MDI:
-	    // re-use the last top widget to open the file
-	    if (!m_top_widgets.isEmpty())
-		new_top_widget = m_top_widgets.last();
-	    break;
-	case Kwave::App::GUI_SDI:
-	    // always create a new top widget, except when handling commands
-	    if ( (url.scheme().toLower() == Kwave::urlScheme()) &&
-		 !m_top_widgets.isEmpty() )
-		new_top_widget = m_top_widgets.last();
-	    break;
+        case Kwave::App::GUI_TAB: /* FALLTHROUGH */
+        case Kwave::App::GUI_MDI:
+            // re-use the last top widget to open the file
+            if (!m_top_widgets.isEmpty())
+                new_top_widget = m_top_widgets.last();
+            break;
+        case Kwave::App::GUI_SDI:
+            // always create a new top widget, except when handling commands
+            if ( (url.scheme().toLower() == Kwave::urlScheme()) &&
+                 !m_top_widgets.isEmpty() )
+                new_top_widget = m_top_widgets.last();
+            break;
     }
 
     if (!new_top_widget) {
-	new_top_widget = new(std::nothrow) Kwave::TopWidget(*this);
-	if (!new_top_widget || !new_top_widget->init()) {
-	    // init failed
-	    qWarning("ERROR: initialization of TopWidget failed");
-	    delete new_top_widget;
-	    return ECANCELED;
-	}
+        new_top_widget = new(std::nothrow) Kwave::TopWidget(*this);
+        if (!new_top_widget || !new_top_widget->init()) {
+            // init failed
+            qWarning("ERROR: initialization of TopWidget failed");
+            delete new_top_widget;
+            return ECANCELED;
+        }
 
-	if (!m_top_widgets.isEmpty()) {
-	    // create a new widget with the same geometry as
-	    // the last created one
-	    const QRect &geom = m_top_widgets.last()->geometry();
-	    // calling setGeometry(geom) would overlap :-(
-	    new_top_widget->resize(geom.width(), geom.height());
-	}
+        if (!m_top_widgets.isEmpty()) {
+            // create a new widget with the same geometry as
+            // the last created one
+            const QRect &geom = m_top_widgets.last()->geometry();
+            // calling setGeometry(geom) would overlap :-(
+            new_top_widget->resize(geom.width(), geom.height());
+        }
 
-	m_top_widgets.append(new_top_widget);
-	new_top_widget->show();
+        m_top_widgets.append(new_top_widget);
+        new_top_widget->show();
 
-	// inform the widget about changes in the list of recent files
-	connect(this, SIGNAL(recentFilesChanged()),
-		new_top_widget, SLOT(updateRecentFiles()));
+        // inform the widget about changes in the list of recent files
+        connect(this, SIGNAL(recentFilesChanged()),
+                new_top_widget, SLOT(updateRecentFiles()));
     }
 
     retval = (!url.isEmpty()) ? new_top_widget->loadFile(url) : 0;
     if (retval == ECANCELED)
-	delete new_top_widget;
+        delete new_top_widget;
 
     Kwave::Splash::showMessage(i18n("Startup done"));
     return retval;
@@ -283,7 +283,7 @@ bool Kwave::App::toplevelWindowHasClosed(Kwave::TopWidget *todel)
 
     // remove the toplevel widget from our list
     if (m_top_widgets.contains(todel))
-	m_top_widgets.removeAll(todel);
+        m_top_widgets.removeAll(todel);
 
     // if list is empty -> no more windows there -> exit application
     return (m_top_widgets.isEmpty());
@@ -294,10 +294,10 @@ QList<Kwave::App::FileAndInstance> Kwave::App::openFiles() const
 {
     QList<Kwave::App::FileAndInstance> all_files;
     foreach (const Kwave::TopWidget *topwidget, m_top_widgets) {
-	if (!topwidget) continue;
-	QList<Kwave::App::FileAndInstance> files = topwidget->openFiles();
-	if (!files.isEmpty())
-	    all_files += files;
+        if (!topwidget) continue;
+        QList<Kwave::App::FileAndInstance> files = topwidget->openFiles();
+        if (!files.isEmpty())
+            all_files += files;
     }
     return all_files;
 }
@@ -314,14 +314,14 @@ void Kwave::App::switchGuiType(Kwave::TopWidget *top, GuiType new_type)
     QList<Kwave::FileContext *> all_contexts;
     QMutableListIterator<Kwave::TopWidget *> it(m_top_widgets);
     while (it.hasNext()) {
-	Kwave::TopWidget *topwidget = it.next();
-	if (!topwidget) { it.remove(); continue; }
-	QList<Kwave::FileContext *> contexts = topwidget->detachAllContexts();
-	if (!contexts.isEmpty()) all_contexts += contexts;
-	if (topwidget != top) {
-	    it.remove();
-	    delete topwidget;
-	}
+        Kwave::TopWidget *topwidget = it.next();
+        if (!topwidget) { it.remove(); continue; }
+        QList<Kwave::FileContext *> contexts = topwidget->detachAllContexts();
+        if (!contexts.isEmpty()) all_contexts += contexts;
+        if (topwidget != top) {
+            it.remove();
+            delete topwidget;
+        }
     }
 
     // from now on use the new GUI type
@@ -330,60 +330,62 @@ void Kwave::App::switchGuiType(Kwave::TopWidget *top, GuiType new_type)
     // at this point we should have exactly one toplevel widget without
     // context and a list of contexts (which may be empty)
     if (!all_contexts.isEmpty()) {
-	bool first = true;
-	foreach (Kwave::FileContext *context, all_contexts) {
+        bool first = true;
+        foreach (Kwave::FileContext *context, all_contexts) {
             Kwave::TopWidget *top_widget = Q_NULLPTR;
 
-	    switch (m_gui_type) {
-		case GUI_SDI:
-		    if (!context->isEmpty() || (all_contexts.count() == 1)) {
-			// either the context contains some signal and is worth
-			// assigning it to a toplevel widget, or it is the one
-			// and only context
-			if (first) {
-			    // the context reuses the calling toplevel widget
-			    top_widget = top;
-			    first = false;
-			} else {
-			    // for all other contexts we have to create a new
-			    // toplevel widget
-			    top_widget = new(std::nothrow) Kwave::TopWidget(*this);
-			    if (!top_widget || !top_widget->init()) {
-				// init failed
-				qWarning("ERROR: initialization of TopWidget failed");
-				delete top_widget;
-				delete context;
-				break;
-			    }
-			    m_top_widgets.append(top_widget);
-			    top_widget->show();
+            switch (m_gui_type) {
+                case GUI_SDI:
+                    if (!context->isEmpty() || (all_contexts.count() == 1)) {
+                        // either the context contains some signal and is worth
+                        // assigning it to a toplevel widget, or it is the one
+                        // and only context
+                        if (first) {
+                            // the context reuses the calling toplevel widget
+                            top_widget = top;
+                            first = false;
+                        } else {
+                            // for all other contexts we have to create a new
+                            // toplevel widget
+                            top_widget = new(std::nothrow)
+                                Kwave::TopWidget(*this);
+                            if (!top_widget || !top_widget->init()) {
+                                // init failed
+                                qWarning("ERROR: initialization of "
+                                         "TopWidget failed");
+                                delete top_widget;
+                                delete context;
+                                break;
+                            }
+                            m_top_widgets.append(top_widget);
+                            top_widget->show();
 
-			    // inform the widget about changes in the list of
-			    // recent files
-			    connect(this, SIGNAL(recentFilesChanged()),
-				    top_widget, SLOT(updateRecentFiles()));
-			}
-		    } else {
-			// probably this context is only executing a script and
-			// has (no longer) any valid signal. We need to assign
-			// it to a toplevel widget for processing further
-			// commands but reduce the reference count to make it
-			// vanish as soon as the script terminates.
-			context->setParent(top);
-			context->release();
-		    }
-		    break;
-		case GUI_MDI: /* FALLTHROUGH */
-		case GUI_TAB:
-		    // all contexts go into the same toplevel widget
-		    top_widget = top;
-		    break;
-	    }
+                            // inform the widget about changes in the list of
+                            // recent files
+                            connect(this, SIGNAL(recentFilesChanged()),
+                                    top_widget, SLOT(updateRecentFiles()));
+                        }
+                    } else {
+                        // probably this context is only executing a script and
+                        // has (no longer) any valid signal. We need to assign
+                        // it to a toplevel widget for processing further
+                        // commands but reduce the reference count to make it
+                        // vanish as soon as the script terminates.
+                        context->setParent(top);
+                        context->release();
+                    }
+                    break;
+                case GUI_MDI: /* FALLTHROUGH */
+                case GUI_TAB:
+                    // all contexts go into the same toplevel widget
+                    top_widget = top;
+                    break;
+            }
 
-	    if (top_widget) top_widget->insertContext(context);
-	}
+            if (top_widget) top_widget->insertContext(context);
+        }
     } else {
-	// give our one and only toplevel widget a default context
+        // give our one and only toplevel widget a default context
         top->insertContext(Q_NULLPTR);
     }
 }
@@ -395,11 +397,11 @@ void Kwave::App::saveRecentFiles()
 
     QString num;
     for (int i = 0 ; i < MAX_RECENT_FILES; i++) {
-	num.setNum(i);
-	if (i < m_recent_files.count())
-	    cfg.writeEntry(num, m_recent_files[i]);
-	else
-	    cfg.deleteEntry(num);
+        num.setNum(i);
+        if (i < m_recent_files.count())
+            cfg.writeEntry(num, m_recent_files[i]);
+        else
+            cfg.deleteEntry(num);
     }
 
     cfg.sync();
@@ -411,17 +413,17 @@ void Kwave::App::readConfig()
     const KConfigGroup cfg = KSharedConfig::openConfig()->group("Recent Files");
 
     for (unsigned int i = 0 ; i < MAX_RECENT_FILES; i++) {
-	QString key = QString::number(i);        // generate number
+        QString key = QString::number(i);        // generate number
 
-	// read corresponding entry, which is stored in UTF-8
-	QString result = cfg.readEntry(key);
-	if (result.length()) {
-	    QFile file(result);
+        // read corresponding entry, which is stored in UTF-8
+        QString result = cfg.readEntry(key);
+        if (result.length()) {
+            QFile file(result);
 
-	    //check if file exists and insert it if not already present
-	    if (file.exists() && (m_recent_files.contains(result) == 0))
-		m_recent_files.append(result);
-	}
+            //check if file exists and insert it if not already present
+            if (file.exists() && (m_recent_files.contains(result) == 0))
+                m_recent_files.append(result);
+        }
     }
 }
 
